@@ -11,7 +11,7 @@
     :copyright: Copyright 2008-2014 Deutsches Zentrum fuer Luft- und Raumfahrt e.V.
     :copyright: Copyright 2011-2014 Marc Rautenhaus (mr), Tongxi Lou (tl)
     :copyright: Copyright 2016-2017 Reimar Bauer
-    :copyright: Copyright 2016-2017 by the mss team, see AUTHORS.
+    :copyright: Copyright 2016-2018 by the mss team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -30,12 +30,12 @@
 
 import os
 
-HOME = os.path.expanduser("~")
-MSS_CONFIG_PATH = os.getenv("MSS_CONFIG_PATH", os.path.join(HOME, ".config", "mss"))
+HOME = os.path.expanduser("~/")
+MSS_CONFIG_PATH = os.getenv("MSS_CONFIG_PATH", os.path.join(HOME, u".config", u"mss"))
 if not os.path.exists(MSS_CONFIG_PATH):
     os.makedirs(MSS_CONFIG_PATH)
 
-MSS_SETTINGS = os.getenv('MSS_SETTINGS', os.path.join(MSS_CONFIG_PATH, "mss_settings.json"))
+MSS_SETTINGS = os.getenv('MSS_SETTINGS', os.path.join(MSS_CONFIG_PATH, u"mss_settings.json"))
 
 WMS_LOGIN_CACHE = {}
 CACHED_CONFIG_FILE = None
