@@ -18,7 +18,7 @@
 
     :copyright: Copyright 2008-2014 Deutsches Zentrum fuer Luft- und Raumfahrt e.V.
     :copyright: Copyright 2011-2014 Marc Rautenhaus (mr)
-    :copyright: Copyright 2016-2017 by the mss team, see AUTHORS.
+    :copyright: Copyright 2016-2018 by the mss team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -37,16 +37,17 @@
 from __future__ import division
 
 from builtins import str
+from past.builtins import unicode
 
 import datetime
-import codecs
 import logging
 import os
 import xml.dom.minidom
 import xml.parsers.expat
+from fs import open_fs
 
 # related third party imports
-from mslib.msui.mss_qt import QtGui, QtCore, QtWidgets, QString, variant_to_string, variant_to_float, USE_PYQT5
+from mslib.msui.mss_qt import QtGui, QtCore, QtWidgets, variant_to_string, variant_to_float
 
 # local application imports
 from mslib import utils, __version__
@@ -55,7 +56,8 @@ from mslib.utils import config_loader, find_location, save_settings_pickle, load
 from mslib.msui.performance_settings import DEFAULT_PERFORMANCE
 from mslib.msui import MissionSupportSystemDefaultConfig as mss_default
 
-
+from mslib.utils import writexml
+xml.dom.minidom.Element.writexml = writexml
 # Constants for identifying the table columns when the WaypointsTableModel is
 # used with a QTableWidget.
 LOCATION, LAT, LON, FLIGHTLEVEL, PRESSURE = list(range(5))
@@ -155,7 +157,7 @@ class WaypointsTableModel(QtCore.QAbstractTableModel):
         self.load_settings()
 
         # If a filename is passed to the constructor, load data from this file.
-        if filename:
+        if filename is not None:
             if filename.endswith(".ftml"):
                 self.load_from_ftml(filename)
             else:
@@ -419,7 +421,7 @@ class WaypointsTableModel(QtCore.QAbstractTableModel):
         """
         waypoints = self.waypoints
 
-        def get_duration_fuel(flightlevel0, flightlevel1, distance, weight):
+        def get_duration_fuel(flightlevel0, flightlevel1, distance, weight, lastleg):
             aircraft = self.performance_settings["aircraft"]
             if flightlevel0 == flightlevel1:
                 tas, fuelflow = aircraft.get_cruise_performance(flightlevel0 * 100, weight)
@@ -436,7 +438,10 @@ class WaypointsTableModel(QtCore.QAbstractTableModel):
                 duration = (duration1 - duration0) * 60  # convert from min to s
                 dist = (dist1 - dist0) * 1.852  # convert from nm to km
                 fuel = fuel1 - fuel0
-                duration_p, fuel_p = get_duration_fuel(flightlevel1, flightlevel1, distance - dist, weight)
+                if lastleg:
+                    duration_p, fuel_p = get_duration_fuel(flightlevel0, flightlevel0, distance - dist, weight, False)
+                else:
+                    duration_p, fuel_p = get_duration_fuel(flightlevel1, flightlevel1, distance - dist, weight, False)
                 return duration + duration_p, fuel + fuel_p
 
         pos = position
@@ -459,7 +464,9 @@ class WaypointsTableModel(QtCore.QAbstractTableModel):
                 wp1.distance_to_prev = utils.get_distance((wp0.lat, wp0.lon),
                                                           (wp1.lat, wp1.lon))
 
-                time, fuel = get_duration_fuel(wp0.flightlevel, wp1.flightlevel, wp1.distance_to_prev, wp0.weight)
+                last = (pos - 1 == rows)
+                time, fuel = get_duration_fuel(
+                    wp0.flightlevel, wp1.flightlevel, wp1.distance_to_prev, wp0.weight, lastleg=last)
                 wp1.leg_time = time
                 wp1.cum_time = wp0.cum_time + wp1.leg_time
                 wp1.utc_time = wp0.utc_time + datetime.timedelta(seconds=wp1.leg_time)
@@ -480,7 +487,9 @@ class WaypointsTableModel(QtCore.QAbstractTableModel):
             wp1 = waypoints[i]
             wp1.distance_total = wp0.distance_total + wp1.distance_to_prev
             wp1.weight = wp0.weight - wp0.leg_fuel
-            time, fuel = get_duration_fuel(wp0.flightlevel, wp1.flightlevel, wp1.distance_to_prev, wp0.weight)
+            last = (i + 1 == len(waypoints))
+            time, fuel = get_duration_fuel(
+                wp0.flightlevel, wp1.flightlevel, wp1.distance_to_prev, wp0.weight, lastleg=last)
 
             wp1.leg_time = time
             wp1.cum_time = wp0.cum_time + wp1.leg_time
@@ -528,32 +537,37 @@ class WaypointsTableModel(QtCore.QAbstractTableModel):
 
         doc = xml.dom.minidom.Document()
 
-        ft_el = doc.createElement("FlightTrack")
-        ft_el.setAttribute("version", str(__version__))
+        ft_el = doc.createElement(u"FlightTrack")
+        ft_el.setAttribute(u"version", unicode(__version__))
         doc.appendChild(ft_el)
         # The list of waypoint elements.
-        wp_el = doc.createElement("ListOfWaypoints")
+        wp_el = doc.createElement(u"ListOfWaypoints")
         ft_el.appendChild(wp_el)
 
         for wp in self.waypoints:
-            element = doc.createElement("Waypoint")
+            element = doc.createElement(u"Waypoint")
             wp_el.appendChild(element)
-            element.setAttribute("location", str(wp.location))
-            element.setAttribute("lat", str(wp.lat))
-            element.setAttribute("lon", str(wp.lon))
-            element.setAttribute("flightlevel", str(wp.flightlevel))
-            comments = doc.createElement("Comments")
-            comments.appendChild(doc.createTextNode(str(wp.comments)))
+            element.setAttribute(u"location", unicode(wp.location))
+            element.setAttribute(u"lat", unicode(wp.lat))
+            element.setAttribute(u"lon", unicode(wp.lon))
+            element.setAttribute(u"flightlevel", unicode(wp.flightlevel))
+            comments = doc.createElement(u"Comments")
+            comments.appendChild(doc.createTextNode(unicode(wp.comments)))
             element.appendChild(comments)
 
-        with codecs.open(self.filename, 'w', encoding="utf-8") as file_object:
-            doc.writexml(file_object, indent="  ", addindent="  ", newl="\n", encoding="utf-8")
+        _dirname, _name = os.path.split(self.filename)
+        _fs = open_fs(_dirname)
+        with _fs.open(_name, 'w') as file_object:
+            doc.writexml(file_object, indent=u"  ", addindent=u"  ", newl=u"\n", encoding=u"utf-8")
 
     def load_from_ftml(self, filename):
         """Load a flight track from an XML file at <filename>.
         """
+        _dirname, _name = os.path.split(filename)
+        _fs = open_fs(_dirname)
+        datasource = _fs.open(_name)
         try:
-            doc = xml.dom.minidom.parse(filename)
+            doc = xml.dom.minidom.parse(datasource)
         except xml.parsers.expat.ExpatError as ex:
             raise SyntaxError(str(ex))
 
@@ -634,10 +648,7 @@ class WaypointDelegate(QtWidgets.QItemDelegate):
             return QtWidgets.QItemDelegate.createEditor(self, parent, option, index)
 
     def setEditorData(self, editor, index):
-        if USE_PYQT5:
-            text = index.model().data(index, QtCore.Qt.DisplayRole).value()
-        else:
-            text = index.model().data(index, QtCore.Qt.DisplayRole).toString()
+        text = index.model().data(index, QtCore.Qt.DisplayRole).value()
         if index.column() in (LOCATION,):
             i = editor.findText(text)
             if i == -1:
