@@ -8,7 +8,7 @@
 
     This file is part of mss.
 
-    :copyright: Copyright 2016-2017 by the mss team, see AUTHORS.
+    :copyright: Copyright 2016-2018 by the mss team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -36,9 +36,9 @@ ICONSIZE = [
 ]
 
 
-def icons(icon_size):
+def icons(icon_size, name="mss-logo.png"):
     if icon_size in ICONSIZE:
-        return os.path.join(os.path.abspath(os.path.normpath(os.path.dirname(__file__))), icon_size, "mss-logo.png")
+        return os.path.join(os.path.abspath(os.path.normpath(os.path.dirname(__file__))), icon_size, name)
 
 
 def python_powered():
