@@ -4,7 +4,7 @@
     mslib.msui.mss_pyui
     ~~~~~~~~~~~~~~~~~~~
 
-    Mission Support System Python/Qt4 User Interface
+    Mission Support System Python/Qt User Interface
     Main window of the user interface application. Manages view and tool windows
     (the user can open multiple windows) and provides functionalty to open, save,
     and switch between flight tracks.
@@ -13,7 +13,7 @@
 
     :copyright: Copyright 2008-2014 Deutsches Zentrum fuer Luft- und Raumfahrt e.V.
     :copyright: Copyright 2011-2014 Marc Rautenhaus (mr)
-    :copyright: Copyright 2016-2017 by the mss team, see AUTHORS.
+    :copyright: Copyright 2016-2018 by the mss team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -30,8 +30,6 @@
 """
 from __future__ import print_function
 
-from builtins import str
-
 import argparse
 import copy
 import functools
@@ -45,6 +43,7 @@ import requests
 import shutil
 import sys
 import types
+import fs
 
 from mslib import __version__
 from mslib.msui.mss_qt import ui_mainwindow as ui
@@ -63,7 +62,7 @@ from mslib.plugins.io.csv import load_from_csv, save_to_csv
 from mslib.msui.icons import icons, python_powered
 
 # related third party imports
-from mslib.msui.mss_qt import QtGui, QtCore, QtWidgets, _translate, _fromUtf8, USE_PYQT5
+from mslib.msui.mss_qt import QtGui, QtCore, QtWidgets, get_open_filename, get_save_filename
 
 try:
     import nappy
@@ -76,7 +75,7 @@ sys.path.append(constants.MSS_CONFIG_PATH)
 
 
 def clean_string(string):
-    return re.sub('\W|^(?=\d)', '_', string)
+    return re.sub(r'\W|^(?=\d)', '_', string)
 
 
 class QActiveViewsListWidgetItem(QtWidgets.QListWidgetItem):
@@ -133,8 +132,8 @@ class QFlightTrackListWidgetItem(QtWidgets.QListWidgetItem):
                   to name changes of the item.
         """
         view_name = flighttrack_model.name
-        super(QFlightTrackListWidgetItem, self).__init__(view_name, parent,
-                                                         type)
+        super(QFlightTrackListWidgetItem, self).__init__(
+            view_name, parent, type)
 
         self.parent = parent
         self.flighttrack_model = flighttrack_model
@@ -180,7 +179,7 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
         # Reference to the flight track that is currently displayed in the
         # views.
         self.active_flight_track = None
-        self.last_save_directory = os.getcwd()
+        self.last_save_directory = config_loader(dataset="data_dir", default=mss_default.data_dir)
 
         # Connect Qt SIGNALs:
         # ===================
@@ -218,8 +217,8 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
         # Tools.
         self.listTools.itemActivated.connect(self.activate_sub_window)
 
-        self.add_import_filter("CSV", "csv", load_from_csv)
-        self.add_export_filter("CSV", "csv", save_to_csv)
+        self.add_import_filter("CSV", "csv", load_from_csv, pickertag="filepicker_flightrack")
+        self.add_export_filter("CSV", "csv", save_to_csv, pickertag="filepicker_flightrack")
 
         self._imported_plugins, self._exported_plugins = {}, {}
         self.add_plugins()
@@ -242,9 +241,8 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
         for i, base_url in enumerate(urls):
             pdlg.setValue(i)
             QtWidgets.QApplication.processEvents()
-            logging.info(base_url)
             # initialize login cache fomr config file, but do not overwrite existing keys
-            for key, value in list(config_loader(dataset="WMS_login", default={}).items()):
+            for key, value in config_loader(dataset="WMS_login", default={}).items():
                 if key not in constants.WMS_LOGIN_CACHE:
                     constants.WMS_LOGIN_CACHE[key] = value
             username, password = constants.WMS_LOGIN_CACHE.get(base_url, (None, None))
@@ -265,9 +263,15 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
         pdlg.close()
 
     def add_plugins(self):
+        picker_default = config_loader(
+            dataset="filepicker_default", default=mss_default.filepicker_default)
+
         self._imported_plugins = config_loader(dataset="import_plugins", default={})
         for name in self._imported_plugins:
-            extension, module, function = self._imported_plugins[name]
+            extension, module, function = self._imported_plugins[name][:3]
+            picker_type = picker_default
+            if len(self._imported_plugins[name]) == 4:
+                picker_type = self._imported_plugins[name][3]
             try:
                 imported_module = importlib.import_module(module)
             # wildcard exception to be resilient against error introduced by user code
@@ -279,7 +283,7 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
                         self._imported_plugins, type(ex), ex)))
                 continue
             try:
-                self.add_import_filter(name, extension, getattr(imported_module, function))
+                self.add_import_filter(name, extension, getattr(imported_module, function), pickertype=picker_type)
             # wildcard exception to be resilient against error introduced by user code
             except Exception as ex:
                 logging.error(u"Error on installing plugin: %s: %s", type(ex), ex)
@@ -291,7 +295,10 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
 
         self._exported_plugins = config_loader(dataset="export_plugins", default={})
         for name in self._exported_plugins:
-            extension, module, function = self._exported_plugins[name]
+            extension, module, function = self._exported_plugins[name][:3]
+            picker_type = picker_default
+            if len(self._exported_plugins[name]) == 4:
+                picker_type = self._exported_plugins[name][3]
             try:
                 imported_module = importlib.import_module(module)
             # wildcard exception to be resilient against error introduced by user code
@@ -303,7 +310,7 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
                         self._exported_plugins, type(ex), ex)))
                 continue
             try:
-                    self.add_export_filter(name, extension, getattr(imported_module, function))
+                    self.add_export_filter(name, extension, getattr(imported_module, function), pickertype=picker_type)
             # wildcard exception to be resilient against error introduced by user code
             except Exception as ex:
                 logging.error(u"Error on installing plugin: %s: %s", type(ex), ex)
@@ -317,7 +324,7 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
         for name in self._imported_plugins:
             full_name = "actionImportFlightTrack" + clean_string(name)
             actions = [_x for _x in self.menuImport_Flight_Track.actions()
-                       if _x.objectName() == _fromUtf8(full_name)]
+                       if _x.objectName() == full_name]
             assert len(actions) == 1
             self.menuImport_Flight_Track.removeAction(actions[0])
             delattr(self, full_name)
@@ -325,26 +332,26 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
         for name in self._exported_plugins:
             full_name = "actionExportFlightTrack" + clean_string(name)
             actions = [_x for _x in self.menuExport_Active_Flight_Track.actions()
-                       if _x.objectName() == _fromUtf8(full_name)]
+                       if _x.objectName() == full_name]
             assert len(actions) == 1
             self.menuExport_Active_Flight_Track.removeAction(actions[0])
             delattr(self, full_name)
 
-    def add_import_filter(self, name, extension, function):
+    def add_import_filter(self, name, extension, function, pickertag=None, pickertype=None):
         full_name = "actionImportFlightTrack" + clean_string(name)
         if hasattr(self, full_name):
             raise ValueError(u"'{}' has already been set!".format(full_name))
 
         action = QtWidgets.QAction(self)
-        action.setObjectName(_fromUtf8(full_name))
-        action.setText(_translate("MSSMainWindow", name, None))
+        action.setObjectName(full_name)
+        action.setText(QtCore.QCoreApplication.translate("MSSMainWindow", name, None))
         self.menuImport_Flight_Track.addAction(action)
 
         def load_function_wrapper(self):
-            filename = QtWidgets.QFileDialog.getOpenFileName(
-                self, "Import Flight Track", self.last_save_directory, name + " (*." + extension + ")")
-            filename = filename[0] if isinstance(filename, tuple) and USE_PYQT5 else str(filename)
-            if filename:
+            filename = get_open_filename(
+                self, u"Import Flight Track", self.last_save_directory,
+                u"All Files (*." + extension + ")", pickertype=pickertype)
+            if filename is not None:
                 try:
                     ft_name, new_waypoints = function(filename)
                 # wildcard exception to be resilient against error introduced by user code
@@ -367,22 +374,22 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
         setattr(self, full_name, types.MethodType(load_function_wrapper, self))
         action.triggered.connect(getattr(self, full_name))
 
-    def add_export_filter(self, name, extension, function):
+    def add_export_filter(self, name, extension, function, pickertag=None, pickertype=None):
         full_name = "actionExportFlightTrack" + clean_string(name)
         if hasattr(self, full_name):
             raise ValueError(u"'{}' has already been set!".format(full_name))
 
         action = QtWidgets.QAction(self)
-        action.setObjectName(_fromUtf8(full_name))
-        action.setText(_translate("MSSMainWindow", name, None))
+        action.setObjectName(full_name)
+        action.setText(QtCore.QCoreApplication.translate("MSSMainWindow", name, None))
         self.menuExport_Active_Flight_Track.addAction(action)
 
         def save_function_wrapper(self):
-            default_filename = os.path.join(self.last_save_directory, self.active_flight_track.name + "." + extension)
-            filename = QtWidgets.QFileDialog.getSaveFileName(
-                self, "Export Flight Track", default_filename, name + " (*." + extension + ")")
-            filename = filename[0] if isinstance(filename, tuple) and USE_PYQT5 else str(filename)
-            if filename:
+            default_filename = self.active_flight_track.name + "." + extension
+            filename = get_save_filename(
+                self, u"Export Flight Track", default_filename,
+                name + " (*." + extension + ")", pickertype=pickertype)
+            if filename is not None:
                 try:
                     function(filename, self.active_flight_track.name, self.active_flight_track.waypoints)
                 # wildcard exception to be resilient against error introduced by user code
@@ -514,7 +521,7 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
                     self.tr("ERROR:Flighttrack template in configuration is too short. "
                             "Please add at least two valid locations."))
 
-        if filename:
+        if filename is not None:
             waypoints_model = ft.WaypointsTableModel(filename=filename)
         else:
             # Create a new flight track from the waypoints template.
@@ -544,10 +551,10 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
             self.tr("Opening a config file will reset application. Continue?"),
             QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.No, QtWidgets.QMessageBox.No)
         if ret == QtWidgets.QMessageBox.Yes:
-            filename = QtWidgets.QFileDialog.getOpenFileName(
-                self, "Open Config file", "", "Supported files (*.json *.txt)")
-            filename = filename[0] if isinstance(filename, tuple) and USE_PYQT5 else str(filename)
-            if filename:
+            filename = get_open_filename(
+                self, u"Open Config file", constants.MSS_CONFIG_PATH, u'Config Files (*.json)',
+                pickertag="filepicker_config")
+            if filename is not None:
                 self.listViews.clear()
                 self.listTools.clear()
                 self.remove_plugins()
@@ -558,11 +565,10 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
         """Slot for the 'Open Flight Track' menu entry. Opens a QFileDialog and
            passes the result to createNewFlightTrack().
         """
-        filename = QtWidgets.QFileDialog.getOpenFileName(self,
-                                                         "Open Flight Track", self.last_save_directory,
-                                                         "Flight track XML (*.ftml)")
-        filename = filename[0] if isinstance(filename, tuple) and USE_PYQT5 else str(filename)
-        if filename:
+        filename = get_open_filename(
+            self, u"Open Flight Track", self.last_save_directory, u'Flight Track Files (*.ftml)',
+            pickertag="filepicker_flightrack")
+        if filename is not None:
             try:
                 if filename.endswith('.ftml'):
                     self.create_new_flight_track(filename=filename)
@@ -624,11 +630,11 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
         """Slot for the 'Save Active Flight Track As' menu entry.
         """
         default_filename = os.path.join(self.last_save_directory, self.active_flight_track.name + ".ftml")
-        filename = QtWidgets.QFileDialog.getSaveFileName(
-            self, "Save Flight Track", default_filename, "Flight track XML (*.ftml)")
-        filename = filename[0] if isinstance(filename, tuple) and USE_PYQT5 else str(filename)
+        filename = get_save_filename(
+            self, "Save Flight Track", default_filename, u"Flight Track (*.ftml)", pickertag="filepicker_flightrack")
+        logging.debug("filename : '%s'", filename)
         if filename:
-            self.last_save_directory = os.path.dirname(filename)
+            self.last_save_directory = fs.path.dirname(filename)
             if filename.endswith('.ftml'):
                 try:
                     self.active_flight_track.save_to_ftml(filename)
