@@ -4,12 +4,12 @@
     mslib.msui.mss_qt
     ~~~~~~~~~~~~~~~~~
 
-    This module switches qt4 or qt5
+    This module helps with qt
 
     This file is part of mss.
 
-    :copyright: Copyright 2017 Joern Ungermann
-    :copyright: Copyright 2017 by the mss team, see AUTHORS.
+    :copyright: Copyright 2017 - 2018 Joern Ungermann, Reimar Bauer
+    :copyright: Copyright 2017 - 2018 by the mss team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -27,63 +27,87 @@
 
 import importlib
 import logging
-import traceback
-import sys
+import os
 from past.builtins import unicode
 import platform
+import sys
+import traceback
 
-USE_PYQT5 = False
-try:
-    # import the Qt4Agg FigureCanvas object, that binds Figure to
-    # Qt4Agg backend. It also inherits from QWidget
-    from matplotlib.backends.backend_qt4agg import FigureCanvasQTAgg as FigureCanvas
+from fslib.fs_filepicker import getSaveFileName, getOpenFileName, getExistingDirectory
 
-    # import the NavigationToolbar Qt4Agg widget
-    from matplotlib.backends.backend_qt4agg import NavigationToolbar2QT as NavigationToolbar
+from PyQt5 import QtGui, QtCore, QtWidgets, QtTest
 
-    from PyQt4 import QtGui, QtCore, QtTest
-    QtWidgets = QtGui  # Follow the PyQt5 style and access objects from the modules of PyQt5
-    from PyQt4.QtCore import QString  # import QString as this does not exist in PyQt5
+from mslib.utils import config_loader, FatalUserError
+from mslib.msui import MissionSupportSystemDefaultConfig as mss_default
 
-    QtTest.QTest.qWaitForWindowExposed = QtTest.QTest.qWaitForWindowShown
 
-    def value(self):
-        """
-        Backport of needed stuff from PyQt5 value function
-        """
-        if self.typeName() in ["float", "double"]:
-            result, ok = self.toDouble()
-            if not ok:
-                raise RuntimeError("Problem in converting: {}".format(self))
-            return result
-        if self.typeName() in ["int"]:
-            result, ok = self.toInt()
-            if not ok:
-                raise RuntimeError("Problem in converting: {}".format(self))
-            return result
-        if self.typeName() in ["QString"]:
-            return self.toString()
-        raise RuntimeError("Unsupported type in conversion: {}".format(self.typeName()))
+def get_open_filename_qt(*args):
+    filename = QtWidgets.QFileDialog.getOpenFileName(*args)
+    return filename[0] if isinstance(filename, tuple) else str(filename)
 
-    QtCore.QVariant.value = value
 
-    _qt_ui_prefix = "mslib.msui.qt4."
+def get_save_filename_qt(*args):
+    filename = QtWidgets.QFileDialog.getSaveFileName(*args)
+    return filename[0] if isinstance(filename, tuple) else str(filename)
 
-except ImportError:
-    logging.warning("Did not find PyQt4. Switching to PyQt5.")
-    # import the Qt5Agg FigureCanvas object, that binds Figure to
-    # Qt5Agg backend. It also inherits from QWidget
-    from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg as FigureCanvas
 
-    # import the NavigationToolbar Qt5Agg widget
-    from matplotlib.backends.backend_qt5agg import NavigationToolbar2QT as NavigationToolbar
+def get_existing_directory_qt(*args):
+    dirname = QtWidgets.QFileDialog.getExistingDirectory(*args)
+    return dirname[0] if isinstance(dirname, tuple) else str(dirname)
 
-    from PyQt5 import QtGui, QtCore, QtWidgets, QtTest
-    QString = str  # QString is not exposed anymore but is used transparently by PyQt5
 
-    _qt_ui_prefix = "mslib.msui.qt5."
+def get_pickertype(tag, typ):
+    default = config_loader(dataset="filepicker_default", default=mss_default.filepicker_default)
+    if typ is None:
+        if tag is None:
+            typ = default
+        else:
+            typ = config_loader(dataset=tag, default=default)
+    return typ
 
-    USE_PYQT5 = True
+
+def get_open_filename(parent, title, dirname, filt, pickertag=None, pickertype=None):
+    pickertype = get_pickertype(pickertag, pickertype)
+    if pickertype == "fs":
+        filename = getOpenFileName(parent, dirname, filt, title=u"Import Flight Track")
+    elif pickertype in ["qt", "default"]:
+        filename = get_open_filename_qt(parent, title, dirname, filt)
+    else:
+        raise FatalUserError("Unknown file picker type '{}'.".format(pickertype))
+    logging.debug("Selected '%s'", filename)
+    if filename == "":
+        filename = None
+    return filename
+
+
+def get_save_filename(parent, title, filename, filt, pickertag=None, pickertype=None):
+    pickertype = get_pickertype(pickertag, pickertype)
+    if pickertype == "fs":
+        dirname, filename = os.path.split(filename)
+        filename = getSaveFileName(
+            parent, dirname, filt, title=title, default_filename=filename, show_save_action=True)
+    elif pickertype in ["qt", "default"]:
+        filename = get_save_filename_qt(parent, title, filename, filt)
+    else:
+        raise FatalUserError("Unknown file picker type '{}'.".format(pickertype))
+    logging.debug("Selected '%s'", filename)
+    if filename == "":
+        filename = None
+    return filename
+
+
+def get_existing_directory(parent, title, defaultdir, pickertag=None, pickertype=None):
+    pickertype = get_pickertype(pickertag, pickertype)
+    if pickertype == "fs":
+        dirname = getExistingDirectory(parent, title=title, fs_url=defaultdir)[0]
+    elif pickertype in ["qt", "default"]:
+        dirname = get_existing_directory_qt(parent, title, defaultdir)
+    else:
+        raise FatalUserError("Unknown file picker type '{}'.".format(pickertype))
+    logging.debug("Selected '%s'", dirname)
+    if dirname == "":
+        dirname = None
+    return dirname
 
 
 def variant_to_string(variant):
@@ -130,35 +154,10 @@ for mod in [
         "ui_wms_capabilities",
         "ui_wms_dockwidget",
         "ui_wms_password_dialog"]:
-    globals()[mod] = importlib.import_module(_qt_ui_prefix + mod)
+    globals()[mod] = importlib.import_module("mslib.msui.qt5." + mod)
 
 
-# Add some functions that are used.
-# TODO Can probably be tidied up in a neater fashion by rewriting the using code.
-if USE_PYQT5:
-    def _fromUtf8(s):
-        return s
-
-    _translate = QtCore.QCoreApplication.translate
-
-else:
-    try:
-        _fromUtf8 = QtCore.QString.fromUtf8
-    except AttributeError:
-        def _fromUtf8(s):
-            return s
-
-    try:
-        _encoding = QtGui.QApplication.UnicodeUTF8
-
-        def _translate(context, text, disambig):
-            return QtGui.QApplication.translate(context, text, disambig, _encoding)
-    except AttributeError:
-        def _translate(context, text, disambig):
-            return QtGui.QApplication.translate(context, text, disambig)
-
-
-# PyQt5 silently aborts on a Python Exception and PyQt4 does not inform GUI users
+# PyQt5 silently aborts on a Python Exception
 def excepthook(type_, value, traceback_):
     """
     This dumps the error to console, logging (i.e. logfile), and tries to open a MessageBox for GUI users.
