@@ -10,7 +10,7 @@
 
     :copyright: Copyright 2008-2014 Deutsches Zentrum fuer Luft- und Raumfahrt e.V.
     :copyright: Copyright 2011-2014 Marc Rautenhaus (mr)
-    :copyright: Copyright 2016-2017 by the mss team, see AUTHORS.
+    :copyright: Copyright 2016-2018 by the mss team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -40,7 +40,6 @@ from mslib.msui.mss_qt import QtGui, QtWidgets
 from mslib.msui.mss_qt import ui_sideview_window as ui
 from mslib.msui.mss_qt import ui_sideview_options as ui_opt
 from mslib.msui.viewwindows import MSSMplViewWindow
-from mslib.msui import mpl_pathinteractor as mpl_pi
 from mslib.msui import wms_control as wms
 from mslib.msui.icons import icons
 
@@ -196,7 +195,7 @@ class MSS_SV_OptionsDialog(QtWidgets.QDialog, ui_opt.Ui_SideViewOptionsDialog):
 
 
 class MSSSideViewWindow(MSSMplViewWindow, ui.Ui_SideViewWindow):
-    """PyQt4 window implementing a matplotlib canvas as an interactive
+    """PyQt window implementing a matplotlib canvas as an interactive
        side view flight track editor.
     """
     name = "Side View"
@@ -227,15 +226,6 @@ class MSSSideViewWindow(MSSMplViewWindow, ui.Ui_SideViewWindow):
         # Tool opener.
         self.cbTools.currentIndexChanged.connect(self.openTool)
 
-        # Controls to interact with the flight track.
-        # (For usage of the functools.partial() function, see Chapter 4 (Section
-        # Signals and Slots) of 'Rapid GUI Programming with Python and Qt: The
-        # Definitive Guide to PyQt Programming' (Mark Summerfield).)
-        wpi = self.mpl.canvas.waypoints_interactor
-        self.btMvWaypoint.clicked.connect(functools.partial(wpi.set_edit_mode, mpl_pi.MOVE))
-        self.btInsWaypoint.clicked.connect(functools.partial(wpi.set_edit_mode, mpl_pi.INSERT))
-        self.btDelWaypoint.clicked.connect(functools.partial(wpi.set_edit_mode, mpl_pi.DELETE))
-
     def __del__(self):
         del self.mpl.canvas.waypoints_interactor
 
