@@ -10,7 +10,7 @@
 
     :copyright: Copyright 2008-2014 Deutsches Zentrum fuer Luft- und Raumfahrt e.V.
     :copyright: Copyright 2011-2014 Marc Rautenhaus (mr)
-    :copyright: Copyright 2016-2017 by the mss team, see AUTHORS.
+    :copyright: Copyright 2016-2018 by the mss team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -27,16 +27,16 @@
 """
 
 from builtins import str
-
 import logging
 import os
 
-from mslib.msui.mss_qt import QtCore, QtWidgets, QtGui, USE_PYQT5
+from mslib.msui.mss_qt import QtCore, QtWidgets, QtGui, get_open_filename, get_existing_directory
 from mslib.msui.mss_qt import ui_trajectories_window as ui
 from mslib.msui import trajectory_item_tree as titree
-
 from mslib.msui.viewwindows import MSSViewWindow
 from mslib.msui.icons import icons
+from mslib.msui import MissionSupportSystemDefaultConfig as mss_default
+from mslib.utils import config_loader
 
 
 class MSSTrajectoriesToolWindow(MSSViewWindow, ui.Ui_TrajectoriesWindow):
@@ -51,6 +51,7 @@ class MSSTrajectoriesToolWindow(MSSViewWindow, ui.Ui_TrajectoriesWindow):
         """
         super(MSSTrajectoriesToolWindow, self).__init__(parent)
         self.setupUi(self)
+        self.last_save_directory = config_loader(dataset="data_dir", default=mss_default.data_dir)
         self.setWindowIcon(QtGui.QIcon(icons('64x64')))
 
         self.actionOpenFlightTrack.setEnabled(titree.HAVE_NAPPY)
@@ -114,11 +115,17 @@ class MSSTrajectoriesToolWindow(MSSViewWindow, ui.Ui_TrajectoriesWindow):
            and reads the selected NASA Ames file using nappy.
         """
         # Ask for a file to open, convert the return file name from type
-        # QString to str.
-        nas_file = QtWidgets.QFileDialog.getOpenFileName(
-            self, "Open NASA Ames File", "", "NASA Ames files (*.nas)")
-        nas_file = nas_file[0] if isinstance(nas_file, tuple) and USE_PYQT5 else str(nas_file)
-        if nas_file:
+        filename = get_open_filename(
+            self, "Open NASA Ames File", "", "NASA Ames files (*.nas)",
+            pickertag="filepicker_trajectories")
+        # ToDo nappy needs filelike object first
+        # _dirname, _name = os.path.split(filename)
+        # _fs = open_fs(_dirname)
+        if filename is not None:
+            # until nappy knows filelike objects
+            # nas_file = _fs.open(_name, "wb")
+            nas_file = os.path.expanduser(filename)
+
             logging.debug(u"Loading flight track data from '%s'", nas_file)
 
             # Add the flight track to the data tree.
@@ -138,9 +145,9 @@ class MSSTrajectoriesToolWindow(MSSViewWindow, ui.Ui_TrajectoriesWindow):
            and reads the selected trajectory file using lagrantooutputreader.
         """
         # Ask for a directory to open.
-        traj_dir = QtWidgets.QFileDialog.getExistingDirectory(
-            self, "Open Lagranto Output Directory", "")
-        if traj_dir:
+        traj_dir = get_existing_directory(
+            self, "Open Lagranto Output Directory", self.last_save_directory)
+        if traj_dir is not None:
             logging.debug(u"Loading trajectory data from '%s'", traj_dir)
 
             # Test if selected directory contains subdirectories (as is
