@@ -10,7 +10,7 @@
 
     :copyright: Copyright 2008-2014 Deutsches Zentrum fuer Luft- und Raumfahrt e.V.
     :copyright: Copyright 2011-2014 Marc Rautenhaus (mr)
-    :copyright: Copyright 2016-2017 by the mss team, see AUTHORS.
+    :copyright: Copyright 2016-2018 by the mss team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -45,7 +45,7 @@ import urllib.parse
 import xml.etree.ElementTree as etree
 from mslib.utils import config_loader
 from mslib.msui import MissionSupportSystemDefaultConfig as mss_default
-from mslib.msui.mss_qt import QtCore, QtGui, QtWidgets, USE_PYQT5
+from mslib.msui.mss_qt import QtCore, QtGui, QtWidgets
 
 import mslib.ogcwms
 import owslib.util
@@ -217,7 +217,7 @@ class MSSWebMapService(mslib.ogcwms.WebMapService):
         # to be scanned in urlopen as well as in a following method
         # (urllib2.urlopen objects only allow the content to be read once),
         # the "info" attribute is missing after the conversion..
-        if hasattr(u, "info") and u.info()['Content-Type'] == 'application/vnd.ogc.se_xml':
+        if hasattr(u, "info") and 'application/vnd.ogc.se_xml' in u.info()['Content-Type']:
             se_xml = u.read()
             se_tree = etree.fromstring(se_xml)
             err_message = str(se_tree.find('ServiceException').text).strip()
@@ -555,7 +555,7 @@ class WMSControlWidget(QtWidgets.QWidget, ui.Ui_WMSDockWidget):
         """
         wms = None
         # initialize login cache fomr config file, but do not overwrite existing keys
-        for key, value in list(config_loader(dataset="WMS_login", default={}).items()):
+        for key, value in config_loader(dataset="WMS_login", default={}).items():
             if key not in constants.WMS_LOGIN_CACHE:
                 constants.WMS_LOGIN_CACHE[key] = value
         username, password = constants.WMS_LOGIN_CACHE.get(base_url, (None, None))
@@ -983,8 +983,8 @@ class WMSControlWidget(QtWidgets.QWidget, ui.Ui_WMSDockWidget):
                                                                  self.valid_time_format)
                                     # Parse interval strings of format "PT3H" (= 3 hours)
                                     # or "PT24H" (24 hours).
-                                    time_interval_hours = int(re.match("PT(\d+)H",
-                                                                       list_desc[2]).group(1))
+                                    time_interval_hours = int(
+                                        re.match(r"PT(\d+)H", list_desc[2]).group(1))
 
                                     # Register all time values of the list.
                                     while time_val <= end_time:
@@ -1325,23 +1325,14 @@ class WMSControlWidget(QtWidgets.QWidget, ui.Ui_WMSDockWidget):
         self.tbValidTime_cbfwd.setEnabled(enable)
 
     def get_layer(self):
-        if USE_PYQT5:
-            return self.cbLayer.currentText().split(" | ")[-1]
-        else:
-            return str(self.cbLayer.currentText(), errors="ignore").split(" | ")[-1]
+        return self.cbLayer.currentText().split(" | ")[-1]
 
     def get_style(self):
-        if USE_PYQT5:
-            return self.cbStyle.currentText().split(" |")[0]
-        else:
-            return str(self.cbStyle.currentText(), errors="ignore").split(" |")[0]
+        return self.cbStyle.currentText().split(" |")[0]
 
     def get_level(self):
         if self.cbLevelOn.isChecked():
-            if USE_PYQT5:
-                return self.cbLevel.currentText().split(" (")[0]
-            else:
-                return str(self.cbLevel.currentText(), errors="ignore").split(" (")[0]
+            return self.cbLevel.currentText().split(" (")[0]
         else:
             return None
 
@@ -1629,7 +1620,6 @@ class VSecWMSControlWidget(WMSControlWidget):
                                                    wms_cache=wms_cache,
                                                    view=view)
         self.waypoints_model = waypoints_model
-        self.btGetMap.setText("get vertical section")
         self.btGetMap.clicked.connect(self.get_vsec)
 
     def setFlightTrackModel(self, model):
@@ -1697,10 +1687,7 @@ class HSecWMSControlWidget(WMSControlWidget):
 
     def level_changed(self):
         if self.cbLevelOn.isChecked():
-            if USE_PYQT5:
-                s = self.cbLevel.currentText()
-            else:
-                s = str(self.cbLevel.currentText(), errors="ignore")
+            s = self.cbLevel.currentText()
             if s == "":
                 return
             lvl = float(s.split(" (")[0])
