@@ -11,7 +11,7 @@
 
     :copyright: Copyright 2008-2014 Deutsches Zentrum fuer Luft- und Raumfahrt e.V.
     :copyright: Copyright 2011-2014 Marc Rautenhaus (mr)
-    :copyright: Copyright 2016-2017 by the mss team, see AUTHORS.
+    :copyright: Copyright 2016-2018 by the mss team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -307,7 +307,7 @@ class MPLBasemapHorizontalSectionStyle(AbstractHorizontalSectionStyle):
                 useful = {}
                 for idx, key in enumerate(BASEMAP_REQUESTS):
                     useful[key] = useful.get(key, 0) + idx
-                least_useful = sorted([(value, key) for key, value in list(useful.items())])[:-basemap_cache_size]
+                least_useful = sorted([(value, key) for key, value in useful.items()])[:-basemap_cache_size]
                 for _, key in least_useful:
                     del BASEMAP_CACHE[key]
                     BASEMAP_REQUESTS[:] = [_x for _x in BASEMAP_REQUESTS if key != _x]
