@@ -47,7 +47,7 @@
 
     :copyright: Copyright 2008-2014 Deutsches Zentrum fuer Luft- und Raumfahrt e.V.
     :copyright: Copyright 2011-2014 Marc Rautenhaus (mr)
-    :copyright: Copyright 2016-2017 by the mss team, see AUTHORS.
+    :copyright: Copyright 2016-2018 by the mss team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -75,7 +75,7 @@ import mpl_toolkits.basemap
 from matplotlib import patheffects
 
 from mslib.mswms.mpl_hsec import MPLBasemapHorizontalSectionStyle
-from mslib.mswms.utils import Targets, get_style_parameters, get_cbar_label_format
+from mslib.mswms.utils import Targets, get_style_parameters, get_cbar_label_format, convert_to
 from mslib.mswms.msschem import MSSChemTargets
 from mslib import thermolib
 
@@ -293,7 +293,7 @@ class HS_SEAStyle_01(MPLBasemapHorizontalSectionStyle):
 
         # Filled contour plot.
         scs = bm.contourf(lonmesh, latmesh, sea,
-                          np.arange(0, 91, 1), cmap=plt.cm.spectral)
+                          np.arange(0, 91, 1), cmap=plt.cm.nipy_spectral)
         if not self.noframe:
             cbar = self.fig.colorbar(scs, fraction=0.05, pad=0.08, shrink=0.7)
             cbar.set_label("Solar Elevation Angle (degrees)")
@@ -310,11 +310,11 @@ class HS_SEAStyle_01(MPLBasemapHorizontalSectionStyle):
                    linewidths=3, linestyles="solid")
         cs2 = bm.contour(lonmesh, latmesh, sea,
                          thin_contours, colors="white", linewidths=1)
-        cs2.clabel(thin_contours, fontsize=14, fmt='%i')
+        cs2.clabel(cs2.levels, fontsize=14, fmt='%i')
         cs3 = bm.contour(lonmesh, latmesh, sea,
                          neg_thin_contours, colors="saddlebrown",
                          linewidths=1, linestyles="solid")
-        cs3.clabel(neg_thin_contours, fontsize=14, fmt='%i')
+        cs3.clabel(fontsize=14, fmt='%i')
 
         # Plot title.
         titlestring = "Solar Elevation Angle "
@@ -429,7 +429,7 @@ class HS_TemperatureStyle_ML_01(MPLBasemapHorizontalSectionStyle):
         tempC = data['air_temperature'] - 273.15
 
         tc = bm.contourf(lonmesh, latmesh, tempC,
-                         np.arange(cmin, cmax, 2), cmap=plt.cm.spectral)
+                         np.arange(cmin, cmax, 2), cmap=plt.cm.nipy_spectral)
         if not self.noframe:
             cbar = self.fig.colorbar(tc, fraction=0.05, pad=0.08, shrink=0.7)
             cbar.set_label("Temperature (degC)")
@@ -511,8 +511,8 @@ class HS_GenericStyle(MPLBasemapHorizontalSectionStyle):
         if not self.noframe:
             cbar = self.fig.colorbar(tc, fraction=0.05, pad=0.08, shrink=0.7,
                                      norm=norm, label=cbar_label, format=cbar_format, ticks=ticks)
-            cbar.set_ticklabels(clevs)
             cbar.set_ticks(clevs)
+            cbar.set_ticklabels(clevs)
         else:
             axins1 = mpl_toolkits.axes_grid1.inset_locator.inset_axes(
                 ax, width="3%", height="40%", loc=cbar_location)
@@ -534,13 +534,13 @@ def make_generic_class(name, entity, vert, add_data=None, add_contours=None,
         add_contours = [("ertel_potential_vorticity", [2, 4, 8, 16], "dimgrey", "dimgrey", "solid", 2, True)]
 
     class fnord(HS_GenericStyle):
-        name = entity + "_" + vert
+        name = u"{}_{}".format(entity, vert)
         dataname = entity
         title = Targets.TITLES.get(entity, entity)
         long_name = entity
         units, unit_scale = Targets.get_unit(entity)
         if units:
-            title += " ({})".format(units)
+            title += u" ({})".format(units)
 
         required_datafields = [(vert, entity)] + add_data
         contours = add_contours
@@ -647,6 +647,10 @@ class HS_TemperatureStyle_PL_01(MPLBasemapHorizontalSectionStyle):
         ("pl", "air_temperature"),
         ("pl", "geopotential_height")]
 
+    def _prepare_datafields(self):
+        self.data["geopotential_height"] = convert_to(
+            self.data["geopotential_height"], self.data_units["geopotential_height"], "m", 1. / 9.81)
+
     def _plot_style(self):
         """
         """
@@ -666,7 +670,7 @@ class HS_TemperatureStyle_PL_01(MPLBasemapHorizontalSectionStyle):
         tempC = data['air_temperature'] - 273.15
 
         tc = bm.contourf(lonmesh, latmesh, tempC,
-                         np.arange(cmin, cmax, 2), cmap=plt.cm.spectral)
+                         np.arange(cmin, cmax, 2), cmap=plt.cm.nipy_spectral)
         if not self.noframe:
             cbar = self.fig.colorbar(tc, fraction=0.05, pad=0.08, shrink=0.7)
             cbar.set_label("Temperature (degC)")
@@ -688,11 +692,15 @@ class HS_TemperatureStyle_PL_01(MPLBasemapHorizontalSectionStyle):
                         linewidths=1, linestyles="solid")
 
         # Plot geopotential height contours.
-        gpm = (self.data["geopotential_height"] / 9.81)
+        gpm = self.data["geopotential_height"]
         geop_contours = np.arange(400, 28000, 40)
         cs = bm.contour(lonmesh, latmesh, gpm,
                         geop_contours, colors="black", linewidths=1)
-        ax.clabel(cs, geop_contours[::2], fontsize=10, fmt='%i')
+        if cs.levels[0] in geop_contours[::2]:
+            lablevels = cs.levels[::2]
+        else:
+            lablevels = cs.levels[1::2]
+        ax.clabel(cs, lablevels, fontsize=10, fmt='%i')
 
         titlestring = "Temperature (degC) and Geopotential Height (m) at " \
             "{:.0f} hPa".format(self.level)
@@ -731,6 +739,10 @@ class HS_GeopotentialWindStyle_PL(MPLBasemapHorizontalSectionStyle):
         ("pl", "eastward_wind"),
         ("pl", "northward_wind")]
 
+    def _prepare_datafields(self):
+        self.data["geopotential_height"] = convert_to(
+            self.data["geopotential_height"], self.data_units["geopotential_height"], "m", 1. / 9.81)
+
     def _plot_style(self):
         """
         """
@@ -787,12 +799,16 @@ class HS_GeopotentialWindStyle_PL(MPLBasemapHorizontalSectionStyle):
                  linewidths=0.5, length=6)
 
         # Plot geopotential height contours.
-        gpm = (self.data["geopotential_height"] / 9.81)
+        gpm = self.data["geopotential_height"]
         gpm_interval = 40 if self.level <= 500 else 20
         geop_contours = np.arange(400, 28000, gpm_interval)
         cs = bm.contour(lonmesh, latmesh, gpm,
                         geop_contours, colors="green", linewidths=2)
-        ax.clabel(cs, geop_contours[::2], fontsize=14, fmt='%i')
+        if cs.levels[0] in geop_contours[::2]:
+            lablevels = cs.levels[::2]
+        else:
+            lablevels = cs.levels[1::2]
+        ax.clabel(cs, lablevels, fontsize=14, fmt='%i')
 
         # Plot title.
         titlestring = "Geopotential Height (m) and Horizontal Wind (m/s) " \
@@ -830,10 +846,10 @@ class HS_RelativeHumidityStyle_PL_01(MPLBasemapHorizontalSectionStyle):
     def _prepare_datafields(self):
         """Computes relative humidity from p, t, q.
         """
-        self.data["relative_humidity"] = \
-            thermolib.rel_hum(self.level * 100.,
-                              self.data["air_temperature"],
-                              self.data["specific_humidity"])
+        self.data["geopotential_height"] = convert_to(
+            self.data["geopotential_height"], self.data_units["geopotential_height"], "m", 1. / 9.81)
+        self.data["relative_humidity"] = thermolib.rel_hum(
+            self.level * 100., self.data["air_temperature"], self.data["specific_humidity"])
 
     def _plot_style(self):
         """
@@ -870,12 +886,16 @@ class HS_RelativeHumidityStyle_PL_01(MPLBasemapHorizontalSectionStyle):
                         np.arange(100, 170, 15), colors="yellow", linewidths=1)
 
         # Plot geopotential height contours.
-        gpm = self.data["geopotential_height"] / 9.81
+        gpm = self.data["geopotential_height"]
         gpm_interval = 40 if self.level <= 500 else 20
         geop_contours = np.arange(400, 28000, gpm_interval)
         cs = bm.contour(lonmesh, latmesh, gpm,
                         geop_contours, colors="darkred", linewidths=2)
-        ax.clabel(cs, geop_contours[::2], fontsize=10, fmt='%i')
+        if cs.levels[0] in geop_contours[::2]:
+            lablevels = cs.levels[::2]
+        else:
+            lablevels = cs.levels[1::2]
+        ax.clabel(cs, lablevels, fontsize=10, fmt='%i')
 
         titlestring = "Relative Humditiy (%%) and Geopotential Height (m) at " \
             "{:.0f} hPa".format(self.level)
@@ -912,10 +932,10 @@ class HS_EQPTStyle_PL_01(MPLBasemapHorizontalSectionStyle):
     def _prepare_datafields(self):
         """Computes relative humidity from p, t, q.
         """
-        self.data["equivalent_potential_temperature"] = \
-            thermolib.eqpt_approx(self.level * 100.,
-                                  self.data["air_temperature"],
-                                  self.data["specific_humidity"])
+        self.data["geopotential_height"] = convert_to(
+            self.data["geopotential_height"], self.data_units["geopotential_height"], "m", 1. / 9.81)
+        self.data["equivalent_potential_temperature"] = thermolib.eqpt_approx(
+            self.level * 100., self.data["air_temperature"], self.data["specific_humidity"])
 
     def _plot_style(self):
         """
@@ -947,17 +967,25 @@ class HS_EQPTStyle_PL_01(MPLBasemapHorizontalSectionStyle):
         cs = bm.contour(lonmesh, latmesh, eqpt,
                         thin_contours, colors="grey",
                         linewidths=0.5, linestyles="solid")
-        ax.clabel(cs, thin_contours[::2], colors="grey", fontsize=10, fmt='%i')
+        if cs.levels[0] in thin_contours[::2]:
+            lablevels = cs.levels[::2]
+        else:
+            lablevels = cs.levels[1::2]
+        ax.clabel(cs, lablevels, colors="grey", fontsize=10, fmt='%i')
         # cs = bm.contour(lonmesh, latmesh, eqpt,
         #                np.arange(100, 170, 15), colors="yellow", linewidths=1)
 
         # Plot geopotential height contours.
-        gpm = (self.data["geopotential_height"] / 9.81)
+        gpm = self.data["geopotential_height"]
         gpm_interval = 40 if self.level <= 500 else 20
         geop_contours = np.arange(400, 28000, gpm_interval)
         cs = bm.contour(lonmesh, latmesh, gpm,
                         geop_contours, colors="white", linewidths=2)
-        ax.clabel(cs, geop_contours[::2], fontsize=10, fmt='%i')
+        if cs.levels[0] in geop_contours[::2]:
+            lablevels = cs.levels[::2]
+        else:
+            lablevels = cs.levels[1::2]
+        ax.clabel(cs, lablevels, fontsize=10, fmt='%i')
 
         titlestring = "Equivalent Potential Temperature (degC) and Geopotential Height (m) at " \
                       "{:.0f} hPa".format(self.level)
@@ -994,10 +1022,11 @@ class HS_WStyle_PL_01(MPLBasemapHorizontalSectionStyle):
     def _prepare_datafields(self):
         """Computes relative humidity from p, t, q.
         """
-        self.data["upward_wind"] = \
-            thermolib.omega_to_w(self.data["lagrangian_tendency_of_air_pressure"],
-                                 self.level * 100.,
-                                 self.data["air_temperature"])
+        self.data["geopotential_height"] = convert_to(
+            self.data["geopotential_height"], self.data_units["geopotential_height"], "m", 1. / 9.81)
+        self.data["upward_wind"] = thermolib.omega_to_w(
+            self.data["lagrangian_tendency_of_air_pressure"],
+            self.level * 100., self.data["air_temperature"])
 
     def _plot_style(self):
         """
@@ -1035,12 +1064,16 @@ class HS_WStyle_PL_01(MPLBasemapHorizontalSectionStyle):
         #                np.arange(100, 170, 15), colors="yellow", linewidths=1)
 
         # Plot geopotential height contours.
-        gpm = (self.data["geopotential_height"] / 9.81)
+        gpm = self.data["geopotential_height"]
         gpm_interval = 40 if self.level <= 500 else 20
         geop_contours = np.arange(400, 28000, gpm_interval)
         cs = bm.contour(lonmesh, latmesh, gpm,
                         geop_contours, colors="darkgreen", linewidths=2)
-        ax.clabel(cs, geop_contours[::2], fontsize=10, fmt='%i')
+        if cs.levels[0] in geop_contours[::2]:
+            lablevels = cs.levels[::2]
+        else:
+            lablevels = cs.levels[1::2]
+        ax.clabel(cs, lablevels, fontsize=10, fmt='%i')
 
         titlestring = "Vertical Velocity (cm/s) and Geopotential Height (m) at " \
                       "{:.0f} hPa".format(self.level)
@@ -1073,6 +1106,10 @@ class HS_DivStyle_PL_01(MPLBasemapHorizontalSectionStyle):
         ("pl", "divergence_of_wind"),
         ("pl", "geopotential_height")]
 
+    def _prepare_datafields(self):
+        self.data["geopotential_height"] = convert_to(
+            self.data["geopotential_height"], self.data_units["geopotential_height"], "m", 1. / 9.81)
+
     def _plot_style(self):
         """
         """
@@ -1097,12 +1134,16 @@ class HS_DivStyle_PL_01(MPLBasemapHorizontalSectionStyle):
                         linewidths=2, linestyles="solid")
 
         # Plot geopotential height contours.
-        gpm = (self.data["geopotential_height"] / 9.81)
+        gpm = self.data["geopotential_height"]
         gpm_interval = 40 if self.level <= 500 else 20
         geop_contours = np.arange(400, 28000, gpm_interval)
         cs = bm.contour(lonmesh, latmesh, gpm,
                         geop_contours, colors="darkgreen", linewidths=2)
-        ax.clabel(cs, geop_contours[::2], fontsize=10, fmt='%i')
+        if cs.levels[0] in geop_contours[::2]:
+            lablevels = cs.levels[::2]
+        else:
+            lablevels = cs.levels[1::2]
+        ax.clabel(cs, lablevels, fontsize=10, fmt='%i')
 
         titlestring = "Divergence (positive: red, negative: blue) and Geopotential Height (m) at " \
             "{:.0f} hPa".format(self.level)
@@ -1282,6 +1323,12 @@ class HS_PVTropoStyle_PV_01(MPLBasemapHorizontalSectionStyle):
         ("PT", "Potential Temperature (K)"),
         ("PRES", "Pressure (hPa)")]
 
+    def _prepare_datafields(self):
+        self.data["air_pressure"] = convert_to(
+            self.data["air_pressure"], self.data_units["air_pressure"], "hPa", 1)
+        self.data["geopotential_height"] = convert_to(
+            self.data["geopotential_height"], self.data_units["geopotential_height"], "m", 1. / 9.81)
+
     def _plot_style(self):
         """
         """
@@ -1304,7 +1351,7 @@ class HS_PVTropoStyle_PV_01(MPLBasemapHorizontalSectionStyle):
         if self.style == "PRES":
             filled_contours = np.arange(120, 551, 10)
             thin_contours = np.arange(100, 601, 40)
-            vardata = (data["air_pressure"] / 100.)
+            vardata = data["air_pressure"]
             label = "Pressure (hPa)"
             fcmap = plt.cm.terrain_r
         elif self.style == "PT":
@@ -1316,7 +1363,7 @@ class HS_PVTropoStyle_PV_01(MPLBasemapHorizontalSectionStyle):
         elif self.style == "GEOP":
             filled_contours = np.arange(5000, 15000, 250)
             thin_contours = np.arange(5000, 15000, 500)
-            vardata = (data["geopotential_height"] / 9.81)
+            vardata = data["geopotential_height"]
             label = "Geopotential Height (m)"
             fcmap = plt.cm.terrain
 
@@ -1337,17 +1384,21 @@ class HS_PVTropoStyle_PV_01(MPLBasemapHorizontalSectionStyle):
         cs = bm.contour(lonmesh, latmesh, vardata,
                         thin_contours, colors="yellow",
                         linewidths=0.5, linestyles="solid")
-        ax.clabel(cs, thin_contours[::2], colors="red", fontsize=11, fmt='%i')
+        if cs.levels[0] in thin_contours[::2]:
+            lablevels = cs.levels[::2]
+        else:
+            lablevels = cs.levels[1::2]
+        ax.clabel(cs, lablevels, colors="red", fontsize=11, fmt='%i')
 
         if self.style == "PRES":
             titlestring = "Dynamical Tropopause Pressure (hPa) at " \
-                          "{:.1f} PVU".format(int(self.level) // 1000)
+                          "{:.1f} PVU".format(int(self.level))
         elif self.style == "PT":
             titlestring = "Dynamical Tropopause Potential Temperature (K) at " \
-                          "{:.1f} PVU".format(int(self.level) // 1000)
+                          "{:.1f} PVU".format(int(self.level))
         elif self.style == "GEOP":
             titlestring = "Dynamical Tropopause Geopotential Height (m) at " \
-                          "{:.1f} PVU".format(int(self.level) // 1000)
+                          "{:.1f} PVU".format(int(self.level))
         time_step = self.valid_time - self.init_time
         time_step_hrs = (time_step.days * 86400 + time_step.seconds) // 3600
         titlestring += '\nValid: {} (step {:d} hrs from {})' \
@@ -1427,13 +1478,10 @@ class HS_ThermalTropoStyle_SFC_01(MPLBasemapHorizontalSectionStyle):
                                filled_contours, cmap=fcmap, extend="both")
 
         data["secondary_tropopause_altitude"] = np.ma.masked_invalid(data["secondary_tropopause_altitude"])
-        print(data["tropopause_altitude"].compressed())
-        print(data["secondary_tropopause_altitude"])
 
         if self.style == "default":
-            mask = np.ma.masked_where(
-                data["secondary_tropopause_altitude"].mask, data["secondary_tropopause_altitude"].mask)
-            bm.pcolor(lonmesh, latmesh, mask, alpha=0, hatch="xx")
+            mask = ~data["secondary_tropopause_altitude"].mask
+            bm.contourf(lonmesh, latmesh, mask, [0, 0.5, 1.5], hatches=["", "xx"], alpha=0)
 
         if not self.noframe:
             cbar = self.fig.colorbar(contours, fraction=0.05, pad=0.08, shrink=0.7)
@@ -1444,11 +1492,21 @@ class HS_ThermalTropoStyle_SFC_01(MPLBasemapHorizontalSectionStyle):
             self.fig.colorbar(contours, cax=axins1, orientation="vertical")
             axins1.yaxis.set_ticks_position("left")
 
+            # adjust colorbar fontsize to figure height
+            fontsize = self.fig.bbox.height * 0.024
+            for x in axins1.yaxis.majorTicks:
+                x.label1.set_path_effects([patheffects.withStroke(linewidth=4, foreground='w')])
+                x.label1.set_fontsize(fontsize)
+
         # Colors in python2.6/site-packages/matplotlib/colors.py
         cs = bm.contour(lonmesh, latmesh, vardata,
                         thin_contours, colors="yellow",
                         linewidths=0.5, linestyles="solid")
-        ax.clabel(cs, thin_contours[::2], colors="red", fontsize=11, fmt='%i')
+        if cs.levels[0] in thin_contours[::2]:
+            lablevels = cs.levels[::2]
+        else:
+            lablevels = cs.levels[1::2]
+        ax.clabel(cs, lablevels, colors="red", fontsize=11, fmt='%i')
 
 
 class HS_VIProbWCB_Style_01(MPLBasemapHorizontalSectionStyle):
@@ -1607,6 +1665,13 @@ class HS_BLH_MSLP_Style_01(MPLBasemapHorizontalSectionStyle):
         ("sfc", "air_pressure_at_sea_level"),
         ("sfc", "atmosphere_boundary_layer_thickness")]
 
+    def _prepare_datafields(self):
+        self.data["air_pressure_at_sea_level"] = convert_to(
+            self.data["air_pressure_at_sea_level"], self.data_units["air_pressure_at_sea_level"], "hPa", 1)
+        self.data["atmosphere_boundary_layer_thickness"] = convert_to(
+            self.data["atmosphere_boundary_layer_thickness"],
+            self.data_units["atmosphere_boundary_layer_thickness"], "m", 1)
+
     def _plot_style(self):
         """
         """
@@ -1621,7 +1686,7 @@ class HS_BLH_MSLP_Style_01(MPLBasemapHorizontalSectionStyle):
         thin_contours = [c for c in np.arange(952, 1050, 2)
                          if c not in thick_contours]
 
-        mslp = 0.01 * data["air_pressure_at_sea_level"]
+        mslp = data["air_pressure_at_sea_level"]
 
         # Colors in python2.6/site-packages/matplotlib/colors.py
         cs = bm.contour(lonmesh, latmesh, mslp,
@@ -1782,8 +1847,8 @@ class HS_MSSChemStyle(MPLBasemapHorizontalSectionStyle):
         if not self.noframe:
             cbar = self.fig.colorbar(tc, fraction=0.05, pad=0.08, shrink=0.7,
                                      norm=norm, label=cbar_label, format=cbar_format, ticks=ticks)
-            cbar.set_ticklabels(clevs)
             cbar.set_ticks(clevs)
+            cbar.set_ticklabels(clevs)
         else:
             axins1 = mpl_toolkits.axes_grid1.inset_locator.inset_axes(
                 ax, width="3%", height="40%", loc=cbar_location)
@@ -1808,7 +1873,7 @@ def make_msschem_class(entity, nam, vert, units, scale, add_data=None, add_conto
         _contourname = "_pcontours"
 
     class fnord(HS_MSSChemStyle):
-        name = "HS_" + entity + "_" + vert + _contourname
+        name = u"HS_{}_{}{}".format(entity, vert, _contourname)
         dataname = entity
         units, unit_scale = Targets.get_unit(dataname)
         units = units
@@ -1828,7 +1893,7 @@ def make_msschem_class(entity, nam, vert, units, scale, add_data=None, add_conto
 
 
 for vert in ["ml", "al", "pl"]:
-    for stdname, props in list(MSSChemTargets.items()):
+    for stdname, props in MSSChemTargets.items():
         name, qty, units, scale = props
         key = "HS_MSSChemStyle_" + vert.upper() + "_" + name + "_" + qty
         globals()[key] = make_msschem_class(stdname, name, vert, units, scale)
@@ -1836,7 +1901,7 @@ for vert in ["ml", "al", "pl"]:
 _pressurelevels = np.linspace(5000, 95000, 19)
 _npressurelevels = len(_pressurelevels)
 for vert in ["ml"]:
-    for stdname, props in list(MSSChemTargets.items()):
+    for stdname, props in MSSChemTargets.items():
         name, qty, units, scale = props
         # ToDo string substitution
         key = "HS_MSSChemStyle_" + vert.upper() + "_" + name + "_" + qty + "_pcontours"
