@@ -10,7 +10,7 @@
 
     :copyright: Copyright 2008-2014 Deutsches Zentrum fuer Luft- und Raumfahrt e.V.
     :copyright: Copyright 2011-2014 Marc Rautenhaus (mr)
-    :copyright: Copyright 2016-2017 by the mss team, see AUTHORS.
+    :copyright: Copyright 2016-2018 by the mss team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -430,7 +430,7 @@ class VerticalSectionDriver(MSSPlotDriver):
         lon_indices = lon_data.argsort()
         lon_data = lon_data[lon_indices]
 
-        for name, var in list(self.data_vars.items()):
+        for name, var in self.data_vars.items():
             if len(var.shape) == 4:
                 var_data = var[timestep, ::-self.vert_order, ::self.lat_order, :]
             else:
@@ -594,7 +594,7 @@ class HorizontalSectionDriver(MSSPlotDriver):
             self.actual_level = self.vert_data[level]
         logging.debug("loading data for time step %s (%s), level index %s (level %s)",
                       timestep, self.fc_time, level, self.actual_level)
-        for name, var in list(self.data_vars.items()):
+        for name, var in self.data_vars.items():
             if level is None or len(var.shape) == 3:
                 # 2D fields: time, lat, lon.
                 var_data = var[timestep, ::self.lat_order, :]
