@@ -25,7 +25,7 @@
     :copyright: Copyright 2008-2014 Deutsches Zentrum fuer Luft- und Raumfahrt e.V.
     :copyright: Copyright 2011-2014 Marc Rautenhaus (mr), Omar Qunsul (oq)
     :copyright: Copyright 2016-2017 Reimar Bauer
-    :copyright: Copyright 2016-2017 by the mss team, see AUTHORS.
+    :copyright: Copyright 2016-2018 by the mss team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -54,7 +54,6 @@ import traceback
 import paste
 import paste.request
 import paste.util.multidict
-import tempfile
 import urllib.parse
 from chameleon import PageTemplateLoader
 
@@ -225,7 +224,7 @@ class WMSServer(object):
         # Horizontal Layers
         hsec_layers = []
         for dataset in self.hsec_layer_registry:
-            for layer in list(self.hsec_layer_registry[dataset].values()):
+            for layer in self.hsec_layer_registry[dataset].values():
                 if layer.uses_time_dimensions() and len(layer.get_init_times()) == 0:
                     logging.error("layer %s/%s has no init times!", layer, dataset)
                     continue
@@ -237,7 +236,7 @@ class WMSServer(object):
         # Vertical Layers
         vsec_layers = []
         for dataset in self.vsec_layer_registry:
-            for layer in list(self.vsec_layer_registry[dataset].values()):
+            for layer in self.vsec_layer_registry[dataset].values():
                 if layer.uses_time_dimensions() and len(layer.get_init_times()) == 0:
                     logging.error("layer %s/%s has no init times!", layer, dataset)
                     continue
@@ -518,7 +517,7 @@ def application(environ, start_response):
         logging.debug(u"ENVIRON: %s", environ)
 
         # Processing
-        request = str(query.get('request'))
+        request = query.get('request')
         output = ""
         return_format = 'text/plain'
 
@@ -528,7 +527,7 @@ def application(environ, start_response):
         if request.lower() == 'getcapabilities':
             return_format = 'text/xml'
             return_data = app.get_capabilities(server_url)
-            output = str(return_data).encode('utf-8')
+            output = return_data.encode('utf-8')
         elif request.lower() in ['getmap', 'getvsec']:
             return_data, return_format = app.produce_plot(environ, request)
             # ToDo refactor
@@ -537,7 +536,7 @@ def application(environ, start_response):
                 output = return_data
             else:
                 return_format = "text/xml"
-                output = str(return_data).encode('utf-8')
+                output = return_data.encode('utf-8')
 
         # Preparing the Response
         status = '200 OK'
