@@ -63,6 +63,7 @@ standard_library.install_aliases()
 import cgi
 import xml.etree.ElementTree as etree
 import requests
+import logging
 
 from urllib.parse import urlencode
 from owslib.util import ServiceException
@@ -100,7 +101,7 @@ def openURL(url_base, data=None, method='Get', cookies=None,
 
     if method.lower() == 'post':
         try:
-            xml = etree.fromstring(data)
+            etree.fromstring(data)
             headers['Content-Type'] = 'text/xml'
         except (ParseError, UnicodeEncodeError) as error:
             # (mss)
@@ -113,7 +114,7 @@ def openURL(url_base, data=None, method='Get', cookies=None,
         rkwargs['params'] = data
 
     else:
-        raise ValueError("Unknown method ('%s'), expected 'get' or 'post'" % method)
+        raise ValueError("Unknown method ('{}'), expected 'get' or 'post'".format(method))
 
     if cookies is not None:
         rkwargs['cookies'] = cookies
@@ -132,8 +133,8 @@ def openURL(url_base, data=None, method='Get', cookies=None,
         req.raise_for_status()
 
     # check for service exceptions without the http header set
-    if 'Content-Type' in req.headers and req.headers['Content-Type'] in ['text/xml', 'application/xml',
-                                                                         'application/vnd.ogc.se_xml']:
+    if 'Content-Type' in req.headers and req.headers['Content-Type'] in [
+            'text/xml', 'application/xml', 'application/vnd.ogc.se_xml', 'application/vnd.ogc.wms_xml']:
         # just in case 400 headers were not set, going to have to read the xml to see if it's an exception report.
         se_tree = etree.fromstring(req.content)
 
