@@ -10,7 +10,7 @@
 
     :copyright: Copyright 2008-2014 Deutsches Zentrum fuer Luft- und Raumfahrt e.V.
     :copyright: Copyright 2011-2014 Marc Rautenhaus (mr)
-    :copyright: Copyright 2016-2017 by the mss team, see AUTHORS.
+    :copyright: Copyright 2016-2018 by the mss team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -42,7 +42,7 @@ import paste.util.multidict
 from scipy.interpolate import interp1d
 from scipy.ndimage import map_coordinates
 from mslib.msui import MissionSupportSystemDefaultConfig
-
+from fs import open_fs, errors
 try:
     import mpl_toolkits.basemap.pyproj as pyproj
 except ImportError:
@@ -70,7 +70,8 @@ def config_loader(config_file=None, dataset=None, default=None):
     if config_file is None:
         config_file = constants.CACHED_CONFIG_FILE
     if config_file is None:
-        logging.info('Default MSS config file missing.')
+        logging.info(
+            'Default MSS configuration in place, no user settings, see http://mss.rtfd.io/en/stable/usage.html')
         default_config = dict(MissionSupportSystemDefaultConfig.__dict__)
         if dataset is None:
             return default_config
@@ -79,10 +80,12 @@ def config_loader(config_file=None, dataset=None, default=None):
                 return default_config[dataset]
             except KeyError:
                 return default
+    _dirname, _name = os.path.split(config_file)
+    _fs = open_fs(_dirname)
     try:
-        with open(os.path.join(config_file)) as source:
+        with _fs.open(_name, 'r') as source:
             data = json.load(source)
-    except (AttributeError, IOError, TypeError) as ex:
+    except (AttributeError, IOError, TypeError, errors.ResourceNotFound) as ex:
         logging.error(u"MSS config File error '{:}' - '{:}' - '{:}'".format(config_file, type(ex), ex))
         if default is not None:
             return default
@@ -127,7 +130,7 @@ def find_location(lat, lon, tolerance=5):
     """
     locations = config_loader(dataset='locations', default=MissionSupportSystemDefaultConfig.locations)
     distances = [(get_distance((lat, lon), (loc_lat, loc_lon)), loc)
-                 for loc, (loc_lat, loc_lon) in list(locations.items())]
+                 for loc, (loc_lat, loc_lon) in locations.items()]
     distances.sort()
     if len(distances) > 0 and distances[0][0] <= tolerance:
         return locations[distances[0][1]], distances[0][1]
@@ -145,13 +148,13 @@ def save_settings_pickle(tag, settings):
     """
     assert isinstance(tag, basestring)
     assert isinstance(settings, dict)
-    settingsfile = os.path.join(constants.MSS_CONFIG_PATH, "mss.{}.cfg".format(tag))
+    settingsfile = os.path.join(constants.MSS_CONFIG_PATH, u"mss.{}.cfg".format(tag))
     logging.debug("storing settings for %s to %s", tag, settingsfile)
     try:
         with open(settingsfile, "wb") as fileobj:
             pickle.dump(settings, fileobj)
     except (OSError, IOError) as ex:
-        logging.warn("Problems storing %s settings (%s: %s).", tag, type(ex), ex)
+        logging.warning("Problems storing %s settings (%s: %s).", tag, type(ex), ex)
 
 
 def load_settings_pickle(tag, default_settings=None):
@@ -168,16 +171,18 @@ def load_settings_pickle(tag, default_settings=None):
     if default_settings is None:
         default_settings = {}
     assert isinstance(default_settings, dict)
-    settingsfile = os.path.join(constants.MSS_CONFIG_PATH, "mss.{}.cfg".format(tag))
+    settingsfile = os.path.join(constants.MSS_CONFIG_PATH, u"mss.{}.cfg".format(tag))
+    _dirname, _name = os.path.split(settingsfile)
+    _fs = open_fs(_dirname)
     settings = {}
-    if not os.path.exists(settingsfile):
+    if not _fs.exists(_name):
         logging.debug("settings file '%s' for %s not available", settingsfile, tag)
     else:
         logging.debug("loading settings file '%s' for %s", settingsfile, tag)
         try:
-            with open(settingsfile, "rb") as fileobj:
+            with _fs.open(_name, "rb") as fileobj:
                 settings = pickle.load(fileobj)
-        except (pickle.UnpicklingError, ValueError, KeyError, OSError, IOError, ImportError) as ex:
+        except (pickle.UnpicklingError, ValueError, KeyError, OSError, IOError, ImportError, TypeError) as ex:
             logging.error("Problems reloading stored %s settings (%s: %s). Switching to default",
                           tag, type(ex), ex)
     if isinstance(settings, dict):
@@ -448,3 +453,36 @@ def setup_logging(args):
             fh.setLevel(logging.DEBUG)
             fh.setFormatter(debug_formatter)
             logger.addHandler(fh)
+
+
+# modified Version from minidom, https://github.com/python/cpython/blob/2.7/Lib/xml/dom/minidom.py
+# MSS needed to change all writings as unicode not str
+from xml.dom.minidom import _write_data, Node
+# Copyright © 2001-2018 Python Software Foundation. All rights reserved.
+# Copyright © 2000 BeOpen.com. All rights reserved.
+
+
+def writexml(self, writer, indent=u"", addindent=u"", newl=u""):
+    # indent = current indentation
+    # addindent = indentation to add to higher levels
+    # newl = newline string
+    writer.write(indent + u"<" + self.tagName)
+
+    attrs = self._get_attributes()
+
+    for a_name in sorted(attrs.keys()):
+        writer.write(u" %s=\"" % a_name)
+        _write_data(writer, attrs[a_name].value)
+        writer.write(u"\"")
+    if self.childNodes:
+        writer.write(u">")
+        if (len(self.childNodes) == 1 and self.childNodes[0].nodeType == Node.TEXT_NODE):
+            self.childNodes[0].writexml(writer, '', '', '')
+        else:
+            writer.write(newl)
+            for node in self.childNodes:
+                node.writexml(writer, indent + addindent, addindent, newl)
+            writer.write(indent)
+        writer.write(u"</%s>%s" % (self.tagName, newl))
+    else:
+        writer.write(u"/>%s" % (newl))
